@@ -26,8 +26,12 @@
 ##############################################################################
 #' Predict method for Universal Scalability Law models
 #'
-#' \code{predict} is a function for predictions of the scalability of a
-#' system modeled with the Universal Scalability Law.
+#' \code{predict} is a function for predictions of the scalability of a system
+#' modeled with the Universal Scalability Law. It evaluates the regression
+#' function in the frame \code{newdata} (which defaults to
+#' \code{model.frame(object)}). Setting \code{interval} to "\code{confidence}"
+#' requests the computation of confidence intervals at the specified
+#' \code{level}.
 #'
 #' The parameters \code{sigma} or \code{kappa} are useful to do a what-if
 #' analysis. Setting these parameters override the model parameters and show
@@ -44,8 +48,13 @@
 #'   parameter computed for the model.
 #' @param kappa Optional parameter to be used for evaluation instead of the
 #'   parameter computed for the model.
+#' @param interval Type of interval calculation. Default is to calculate no
+#'   confidence interval.
+#' @param level Confidence level. Default is 0.95.
 #'
-#' @return \code{predict} produces a vector of predictions.
+#' @return \code{predict} produces a vector of predictions or a matrix of
+#'   predictions and bounds with column names \code{fit}, \code{lwr}, and
+#'   \code{upr} if \code{interval} is set to "\code{confidence}".
 #'
 #' @seealso \code{\link{usl}}, \code{\link{scalability,USL-method}},
 #'   \code{\link{USL-class}}
@@ -53,7 +62,7 @@
 #' @references Neil J. Gunther. Guerrilla Capacity Planning: A Tactical
 #'   Approach to Planning for Highly Scalable Applications and Services.
 #'   Springer, Heidelberg, Germany, 1st edition, 2007.
-#'
+#'   
 #' @examples
 #' require(usl)
 #'
@@ -62,12 +71,18 @@
 #' ## Print predicted result from USL model for demo dataset
 #' predict(usl(throughput ~ processors, raytracer))
 #'
+#' ## The same prediction with confidence intervals at the 99% level
+#' predict(usl(throughput ~ processors, raytracer),
+#'         interval = "confidence", level = 0.99)
+#'
 #' @export
 #'
 setMethod(
   f = "predict",
   signature = "USL",
-  definition = function(object, newdata, sigma, kappa) {
+  definition = function(object, newdata, sigma, kappa,
+                        interval = c("none", "confidence"),
+                        level = 0.95) {
     # Predict for the initial data used to create the model
     # if no data frame 'newdata' is given as parameter
     if (missing(newdata)) newdata <- object@frame
@@ -75,12 +90,31 @@ setMethod(
     if (missing(sigma)) sigma <- coef(object)[['sigma']]
     if (missing(kappa)) kappa <- coef(object)[['kappa']]
 
+    if (missing(interval)) interval <- "none"
+
     # Extract regressor variable from data frame
     x <- newdata[, object@regr, drop=TRUE]
 
     # Calculate values (ignore NA)
     y <- scalability(object, sigma, kappa)(x)
 
-    return(structure(y, names=row.names(newdata)))
+    fit <- structure(y, names=row.names(newdata))
+
+    # Return just the vector if the confidence interval is not required
+    if (interval != "confidence") return(fit)
+
+    # The following calculation is taken from
+    # http://perfdynamics.blogspot.de/2010/09/confidence-bands-for-universal.html
+    dof <- length(object@frame[[object@resp]]) - 1L
+
+    y.se  <- sqrt(sum(object@residuals ^ 2) / dof)
+    y.ci  <- y.se * qt(level, dof)
+
+    # Create matrix with fitted value and lower/upper confidence interval
+    mat <- matrix(c(fit, fit - y.ci, fit + y.ci),
+                  nrow = length(fit),
+                  dimnames = list(seq(fit), c("fit", "lwr", "upr")))
+
+    return(mat)
   }
 )
